function [l1, dn, d0] = tldquad1(tl1,dneff,d0eff)

% A function to calculate wire length and raw d's to meet a specification of the total
% vertical height and effective d's at top and bottom at the second top level in a
% quad.
%
% The function looks in the structure pend to find other required data and
% flags, which may include pretty much anything,
% so the call needs to be placed near the end of quadopt.m.
%
% The d*eff arguments are always interpreted as effective d's. If pend.stage2
% is defined and non-zero, flexure correction is applied and the d's
% returned are raw, otherwise flexure correction is omitted and the d's
% returned are effective.
%
% If pend.kxn, pend.kx1 and pend.kx2 are defined, blade lateral correction is
% included.
% 8 Sep 2006: initial release
% 14 Sep 2006: minor tidy-ups
% 15 Oct 2006: rework to eliminate fsolve

global pend;

if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false (wire flexure correction neglected or implicit)
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false (round fibres)
end
if isfield(pend,'g')
    g=pend.g;
else
    g=9.81;
end

M11 = (1/4)*pi*pend.r1^4;
m13	= pend.m1+pend.m2+pend.m3;
blade1 = 0;
if isfield(pend,'kxn')
    if isfield(pend,'kx1')
        if isfield(pend,'kx2')
            blade1 = (g*m13)/(2*pend.kx1);
        end
    end
end

if not(pend.stage2) % old-style, assume flexure correction already applied except for blade component
	dn = dneff + blade1;
	d0 = d0eff;
	l1 = sqrt((tl1-blade1)^2+(pend.n1-pend.n0)^2);
	return;
end

f1=sqrt(pend.nw1*M11*pend.Y1/m13/g); % flexure correction basic factor

% pend.stage2==1 -> new-style
l1 = sqrt((tl1-blade1)^2+(pend.n1-pend.n0)^2); % initial guess
for i=1:5 % hardwire five rounds of Newton-Raphson
	v1=sqrt(l1^2-(pend.n1-pend.n0)^2); % vertical component of wire length
    c1=v1/l1; % cosine of wire angle
    flex1 = f1*c1^(3/2); % flexure correction
	deriv = l1/v1-3*sqrt(v1/l1)*(1/v1-v1/l1^2)*f1; % derivative of tl1 w.r.t. l1
	tl1diff = sqrt(l1^2 - (pend.n0-pend.n1)^2) + dneff + d0eff - 2*flex1 + blade1 - tl1;
	l1 = l1-(tl1diff/deriv);
end
v1=sqrt(l1^2-(pend.n1-pend.n0)^2); % vertical component of wire length
c1=v1/l1; % cosine of wire angle
flex1 = f1*c1^(3/2); % flexure correction
dn = dneff - flex1 + blade1;
d0 = d0eff - flex1;
