function [l2 d1 d2] = tldquad2(tl2, d1eff, d2eff)

% A function to calculate wire length and raw d's to meet a specification of the total
% vertical height and effective d's at top and bottom at the second bottom level in a
% quad.
%
% The function looks in the structure pend to find other required data and
% flags, which may include pretty much anything,
% so the call needs to be placed near the end of quadopt.m.
%
% The d*eff arguments are always interpreted as effective d's. If pend.stage2
% is defined and non-zero, flexure correction is applied and the d's
% returned are raw, otherwise flexure correction is omitted and the d's
% returned are effective.
%
% If pend.kxn, pend.kx1 and pend.kx2 are defined, blade lateral correction is
% included.
% 8 Sep 2006: initial release
% 14 Sep 2006: minor tidy-ups
% 15 Oct 2006: rework to eliminate fsolve

global pend;

if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false (wire flexure correction neglected or implicit)
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false (round fibres)
end
if isfield(pend,'g')
    g=pend.g;
else
    g=9.81;
end

M21 = (1/4)*pi*pend.r2^4;
m23	= pend.m2+pend.m3;
blade2 = 0;
if isfield(pend,'kxn')
    if isfield(pend,'kx1')
        if isfield(pend,'kx2')
            blade2 = (g*m23)/(2*pend.kx2);
        end
    end
end

if not(pend.stage2) % old-style, assume flexure correction already applied except for blade component
	d1 = d1eff + blade2;
	d2 = d2eff;
	l2 = sqrt((tl2-blade2)^2+(pend.n3-pend.n2)^2);
	return;
end

% pend.stage2==1 -> new-style
l2 = sqrt((tl2-blade2)^2+(pend.n3-pend.n2)^2); % initial guess
for i=1:5 % hardwire five rounds of Newton-Raphson
	v2=sqrt(l2^2-(pend.n3-pend.n2)^2); % vertical component of wire length
    c2=v2/l2; % cosine of wire angle
	f2=sqrt(pend.nw2*M21*pend.Y2/m23/g); % flexure correction basic factor
    flex2 = f2*c2^(3/2); % flexure correction
	deriv = l2/v2-3*sqrt(v2/l2)*(1/v2-v2/l2^2)*f2; % derivative of tl2 w.r.t. l2
	tl2diff = sqrt(l2^2 - (pend.n2-pend.n3)^2) + d1eff + d2eff - 2*flex2 + blade2 - tl2;
	l2 = l2-(tl2diff/deriv);
end
v2=sqrt(l2^2-(pend.n3-pend.n2)^2); % vertical component of wire length
c2=v2/l2; % cosine of wire angle
f2=sqrt(pend.nw2*M21*pend.Y2/m23/g); % flexure correction basic factor
flex2 = f2*c2^(3/2); % flexure correction
d1 = d1eff - flex2 + blade2;
d2 = d2eff - flex2;

