function [l3 d3 d4] = tldquad3(tl3, d3eff, d4eff)

% A function to calculate wire length and raw d's to meet a specification of the total
% vertical height and effective d's at top and bottom at the bottom level in a
% quad.
%
% The function looks in the structure pend to find other required data and
% flags, which may include pretty much anything,
% so the call needs to be placed near the end of quadopt.m.
%
% The d*eff arguments are always interpreted as effective d's. If pend.stage2
% is defined and non-zero, flexure correction is applied and the d's
% returned are raw, otherwise flexure correction is omitted and the d's
% returned are effective.
% 8 Sep 2006: initial release
% 14 Sep 2006: removed erroneous factor of 1/4 in M31 for ribbons; minor tidy-ups
% 15 Oct 2006: rework to eliminate fsolve

global pend;

if not(isfield(pend,'stage2'))
    pend.stage2=0; % define, default to false (wire flexure correction neglected or implicit)
end
if not(isfield(pend,'ribbon') )
    pend.ribbon=0; % define, default to false (round fibres)
end
if isfield(pend,'g')
    g=pend.g;
else
    g=9.81;
end

if pend.ribbon
    M31 = pend.W3*pend.t3^3/12;
else
    M31 = (1/4)*pi*pend.r3^4;
end
m3 = pend.m3;

if not(pend.stage2) % old-style, assume flexure correction already applied except for blade component
	d3 = d3eff;
	d4 = d4eff;
	l3 = sqrt(tl3^2+(pend.n5-pend.n4)^2);
	return;
end
f3=sqrt(pend.nw3*M31*pend.Y3/m3/g); % flexure correction basic factor

% pend.stage2==1 -> new-style
l3 = sqrt(tl3^2+(pend.n5-pend.n4)^2); % initial guess
for i=1:5 % hardwire five rounds of Newton-Raphson
	v3=sqrt(l3^2-(pend.n5-pend.n4)^2); % vertical component of wire length
    c3=v3/l3; % cosine of wire angle
    flex3 = f3*c3^(3/2); % flexure correction
	deriv = l3/v3-3*sqrt(v3/l3)*(1/v3-v3/l3^2)*f3; % derivative of tl3 w.r.t. l3
	tl3diff = sqrt(l3^2 - (pend.n4-pend.n5)^2) + d3eff + d4eff - 2*flex3 - tl3;
	l3 = l3-(tl3diff/deriv);
end
v3=sqrt(l3^2-(pend.n5-pend.n4)^2); % vertical component of wire length
c3=v3/l3; % cosine of wire angle
flex3 = f3*c3^(3/2); % flexure correction
d3 = d3eff - flex3;
d4 = d4eff - flex3;
